@@ -5,15 +5,15 @@
  *
  */
 #include "dialog.h"
-#include "ui_dialog.h"
+#include <QDialog>
+#include <QString>
+#include <QWidget>
 
-namespace fcitx {
-namespace unikey {
+namespace fcitx::unikey {
 MacroDialog::MacroDialog(QWidget *parent) : QDialog(parent) { setupUi(this); }
 
 QString MacroDialog::macro() const { return macroLineEdit->text(); }
 
 QString MacroDialog::word() const { return wordLineEdit->text(); }
 
-} // namespace unikey
-} // namespace fcitx
+} // namespace fcitx::unikey
