@@ -52,7 +52,12 @@ public:
 
     int process(unsigned int keyCode, int &backs, unsigned char *outBuf,
                 int &outSize, UkOutputType &outType);
-    void pass(int keyCode); // just pass through without filtering
+    // just pass through without filtering
+    void pass(int keyCode);
+    // rebuild preedit from surrounding char
+    void rebuildChar(VnLexiName ch, int &backs, unsigned char *outBuf,
+                     int &outSize);
+
     void setSingleMode();
 
     int processBackspace(int &backs, unsigned char *outBuf, int &outSize,
